<img src="documentation/pages/images/USGS_ID_white-on-green.png" width=400/>

# **Python Source Code for Updated USGS Risk-Targeted Ground Motion Calculator**

RTGMpy is a python-based library for the calculation of risk-targeted ground motion values, in accordance with ASCE 7 (specific section needed) and AASHTO (specific section needed). 

This library will serve as the source code for the updated [USGS Risk-Targeted Ground Motion Calculator web tool](https://earthquake.usgs.gov/designmaps/rtgm/) (see [here](https://code.usgs.gov/ghsc/hazdev/earthquake-rtgm-calculator/-/wikis/Risk-Targeted-Ground-Motion-Calculator-Documentation) for the original documentation). Updated functionality includes:
- The ability for the user to input and retrieve risk-targeted ground motions for hazard curves for multiple IMs simultaneously
- The ability to obtain risk-targeted motions for multiple design standards (ASCE 7 and AASHTO)

## Prerequisites

TODO - add links
- Python 3.8+
- Poetry - Python dependency manager

## **Installation**

For now, you can clone this repository if you have a USGS account on https://code.usgs.gov/

For CI/CD and security configuration, see the [Guide to Setting up Git and GitLab on your USGS Machine](resources/GitLabStartupGuide.md)

```
$ git clone https://code.usgs.gov/ghsc/erp/rtgm-py-calculator
```

More detailed installation instructions will follow once the library is built and published to `PyPI`


## **Documentation**

Installation and example use cases can be found in the [Wiki](https://code.usgs.gov/ghsc/erp/rtgm-py-calculator/-/wikis/home).

(Under Construction)

## **Basic Usage**

#### Running from the command line
The risk-targeted calculation can be run from the command line by specifying the location of a `.csv` file containing the hazard curve information for the site of interest. An example template can be found in [`rtgmpy/example-haz-inputs/example-hazcurve-input.csv`](https://code.usgs.gov/ghsc/erp/rtgm-py-calculator/-/blob/main/rtgmpy/example-haz-inputs/example-hazcurve-input.csv).

```
$ poetry run rtgm <BuildingCode> </path/to/hazard-curve.csv> </path/to/output.json>(optional)
```
- `<BuildingCode>` designates the construction code document that the risk-targeted calculation is being performed in accordance with, either `ASCE7` or `AASHTO`
- `</path/to/hazard-curve.csv>` is the location of the .csv input file of hazard curve data
- `</path/to/output.json>` (Optional) allows for a user-defined path to the output data. Default is `json-output/output.json`

For example:

```
$ poetry run rtgm ASCE7 rtgmpy/example-haz-inputs/example-hazcurve-input.csv json-output/PortlandASCE7.json
```

Which writes the output file in .json format in the appropriate path [`json-output/PortlandASCE7.json`](https://code.usgs.gov/ghsc/erp/rtgm-py-calculator/-/blob/main/json-output/PortlandASCE7.json)


#### Running in Python

```python
from rtgmpy import BuildingCodeRTGM
```


```python
# Example risk-targeted calculation 
# using ASCE7 guidelines and a random set of hazard curves
rt = BuildingCodeRTGM(BldgCode='AASHTO')
rt.calc_rtgm()
```


```python
rt.siteData
```




    {'name': 'Los Angeles CA', 'lat': 34.05, 'lon': -118.25, 'Vs30': 760.0}




```python
# Summary plot of results
fig,axs = rt.plotRiskCalc('SA1P0');
```


    
![png](documentation/pages/images/ReadMe_src_8_0.png)
    



```python
# Dictionary structure of output data
rt.DATA['summary']
```

```javascript
{
   "PGA": {
      "uhgm": 0.6143624,
      "rtgm": 0.6143624,
      "riskCoeff": 1,
      "colRisk_annual": 2.0296237E-4,
      "timePeriod": 75,
      "colRisk_T": 0.015108428
   },
   "SA0P1": {
      "uhgm": 0.9869936,
      "rtgm": 1.0088047,
      "riskCoeff": 1.0220984,
      "colRisk_annual": 2.0159759E-4,
      "timePeriod": 75,
      "colRisk_T": 0.01500759
   },
   "SA0P5": {
      "uhgm": 1.567971,
      "rtgm": 1.567971,
      "riskCoeff": 1,
      "colRisk_annual": 2.0083315E-4,
      "timePeriod": 75,
      "colRisk_T": 0.014951105
   },
   "SA1P0": {
      "uhgm": 1.143494,
      "rtgm": 1.1636491,
      "riskCoeff": 1.0176259,
      "colRisk_annual": 2.015512E-4,
      "timePeriod": 75,
      "colRisk_T": 0.015004162
   },
   "SA2P0": {
      "uhgm": 0.6717692,
      "rtgm": 0.70291644,
      "riskCoeff": 1.046366,
      "colRisk_annual": 2.0169464E-4,
      "timePeriod": 75,
      "colRisk_T": 0.01501476
   },
   "SA5P0": {
      "uhgm": 0.20698096,
      "rtgm": 0.2161217,
      "riskCoeff": 1.0441623,
      "colRisk_annual": 2.0169705E-4,
      "timePeriod": 75,
      "colRisk_T": 0.015014939
   },
   "SA10P0": {
      "uhgm": 0.07094373,
      "rtgm": 0.07385093,
      "riskCoeff": 1.0409789,
      "colRisk_annual": 2.0168781E-4,
      "timePeriod": 75,
      "colRisk_T": 0.015014256
   }
}
```

## **References**

Luco, N., B.R. Ellingwood, R.O. Hamburger, J.D. Hooper, J.K. Kimball &
C.A. Kircher (2007), "Risk-Targeted versus Current Seismic Design Maps for the
Conterminous United States," *Proceedings of the 2007 Structural Engineers
Association of California Convention*, Lake Tahoe, CA, pp. 163-175.
