import sys
import os
import matplotlib.pyplot as plt
import pandas as pd
import numpy as np
import xarray as xr


class HazardCurveData(object):
    def __init__(self,outputPath,truncated=True):
        self.outPath = outputPath
        self.truncated = truncated
        if self.truncated:
            self.curvesFile = 'curves-truncated.csv'
        else:
            self.curvesFile = 'curves.csv'
        self.get_site_metadata()
    
    def get_site_metadata(self):
        # Get IM labels
        self.IMs = [im for im in os.listdir(self.outPath) if '.' not in im]
        curveDF = pd.read_csv(os.path.join(self.outPath,self.IMs[0],self.curvesFile))
        self.siteDF = curveDF[['name','lon','lat']]

    def parse_single_hazcurve(self,site,im):
        # Parse site data from a given curves file
        curveDF = pd.read_csv(os.path.join(self.outPath,im,self.curvesFile))
        siteCurve = curveDF.loc[curveDF['name']==site]
        # Parse column headers into numpy array of iml values
        iml = np.asarray([float(g) for g in siteCurve.columns[3:]])
        afe = np.asarray(siteCurve[siteCurve.columns[3:]])[0,:]

        # Truncate nan values
        iml = iml[~np.isnan(afe)]
        afe = afe[~np.isnan(afe)]

        # Create dictionary
        hazCurve={}
        hazCurve['site'] = {}
        hazCurve['site']['name'] = site
        hazCurve['site']['lat'] = float(siteCurve['lat'])
        hazCurve['site']['lon'] = float(siteCurve['lon'])
        hazCurve['site']['Vs30'] = None
        hazCurve['IM']=im
        hazCurve['iml'] = iml
        hazCurve['afe']=afe
        return hazCurve

    
    def compile_site_hazcurves(self,site,ims='all',json=False):
        hazCurves = {'site':site,
                'IM':{}}
        if ims == 'all':
            ims = self.IMs
        
        for im in ims:
            # Parse for single data
            hazDict = self.parse_single_hazcurve(site,im)
            if json:
                hazDict['iml'] = hazDict['iml'].tolist()
                hazDict['afe'] = hazDict['afe'].tolist()
            # Add to dictionary
            hazCurves['IM'][hazDict['IM']] = {'iml':hazDict['iml'],
                                         'afe':hazDict['afe']}
        return hazCurves
    
    def compile_site_data(self,site,ims='all',json=False):
        hazCurves = self.compile_site_hazcurves(site,ims,json)
        siteData = {}
        # Site metadata
        siteData['site'] = {}
        siteData['site']['name'] = site
        siteData['site']['lat'] = float(self.siteDF.loc[self.siteDF['name']==site]['lat'])
        siteData['site']['lon'] = float(self.siteDF.loc[self.siteDF['name']==site]['lon'])
        siteData['site']['Vs30'] = 760.0
        # IM information
        siteData['hazCurves'] = hazCurves['IM']
        
        return siteData