1. Introduction and summary of code/algorithm
    - Uniform hazard vs. uniform risk and motivations
    - Risk targets and design guideline criteria
    - Summary of input and output

# 1. Background on Risk-Targeted Ground Motions

One of the most common uses of probabilistic seismic hazard analysis (PSHA) involves the development of seismic design maps in building codes, which typically establishes design ground motion levels corresponding to a target exceedance probability of the ground motion (e.g.,  2% in 50 years). A key limitation of this design basis has been that, while it ensures that design motions correspond to a uniform hazard level, it ultimately does not provide uniform levels of performance, due mainly to the variation in ground motion hazard shapes across different regions, and the lack of incorporation of uncertainty in structural capacity in the selection of a uniform hazard ground motion (Luco et al. 2007).

This limitation motivated the adoption of Risk-Targeted Ground Motions (RTGMs) in the 2009 NEHRP  Provisions, which adjust the uniform-hazard design motions to achieve a targeted collapse probability of 1% in 50 years by incorporating the full ground motion hazard curve and a notional fragility curve for structural collapse.

The objective of the RTGM framework is to ensure uniform structural performance in terms of collapse risk. To represent the collapse capacity of a generic building, Luco et al. (2007) developed a notional fragility curve. This collapse fragility curve is parametrized using the collapse probability under the mapped Risk-Targeted Maximum Considered Earthquake (MCER) ground motion and a lognormal standard deviation of 0.60. Both values are based in part on nonlinear dynamic analyses conducted by the ATC-63 Project (FEMA, 2009), which characterized the average performance level of several archetypal code-compliant lateral systems under mapped motions to have approximately 10% likelihood of collapse. The uncertainty in the collapse capacity (or fragility standard deviation) comes from a combination of record-to-record variability, variability in construction quality, material properties, nonstructural components, and other structural characteristics. 

For a given site, the risk-targeted ground motion corresponding to a specified collapse risk is calculated using an iterative algorithm as described in detail in [Section 2](2-Risk-Targeted-Calc-Procedure.ipynb).

## References
FEMA. (2009). Quantification of Building Seismic Performance Factors, FEMA P-695, prepared by Applied Technology Council for the Federal Emergency Management Agency, Washington, D.C., 292 pp.
