

# 2. Procedure for Calculating Risk-Targeted Ground Motion Values

The procedure for calculating risk-targeted ground motions (RTGM) for a single site is summarized as follows:

1. Upsampling and extending the input ground motion hazard curve

2. Calculating notional fragility curve, anchored to an initial RTGM guess.

3. Integrating the two to calculate the total annualized collapse risk

4. Comparing the calculated collapse risk with the risk targets obtained from the relevant design guideline, and generating a new RTGM guess based on the calculation error.

5. Iterating until the calculated collapse risk is within 1% of the risk target.

It should be noted that this calculation procedure is identical to that implemented in the current USGS Risk-Targeted Calculator; several potential areas of refinement are discussed herein, but the current procedure is adopted here in order to ensure consistency with the risk-targeted design motions already produced for NEHRP 2020 and AASHTO.

## 2.1. Summary of inputs needed for risk-targeted calculation

- Ground motion hazard curve (generally limited to spectral acceleration), covering a sufficient range of intensity measure and exceedance rate values. 
    - These should generally be expressed in terms of annualized frequencies of exceedance (which is the standard output obtained from the USGS NSHM), rather than annual probabilities of exceedance. While functionally these values are numerically equivalent across a broad range of shaking intensities, the use of probabilities may lead to upsampling issues at low intensity levels, where the curves tend to flatten at probabilities of 1.0 (rather than allow for rates of exceedance greater than 1.0).
- Fragility curve parameters:
    - The percentile conditional collapse capacity at which the fragility curve is anchored (e.g., 10% for ASCE7, 5% for AASHTO)
    - The lognormal standard deviation of the collapse capacity (typically taken as 0.60)
- Desired risk targets
    - Return period of uniform hazard motion (e.g., 2475 years for ASCE7, 1033 for AASHTO)
    - Time horizon over which target collapse risk is evaluated (e.g., 50 years for ASCE7, 75 for AASHTO)
    - Target risk of collapse over specified time horizont (e.g., 1% for ASCE7, 1.5% for AASHTO)



## 2.2. Upsampling the ground motion hazard curve

Ground motion hazard curves are typically defined by a discrete set of points, which are generally meant to constrain the reasonable range of ground motion amplitudes of interest for engineering applications, while providing enough resolution to reliably interpret between points at which the PSHA has been performed. Output from the USGS Nation Seismic Hazard Model (NSHM) generally consists of curves with about 20-25 points, with fewer points if the hazard curve outputs have been truncated. 

For use in risk calculations, which typically involve some form of numerical integration, the hazard curve must be defined at a much higher resolution. Furthermore, the upper- and lower-bounds of the hazard curve may need to be extended such that the resulting conditional collapse fragility curves reach probabilities of close to 1.0.

The current method for achieving these two objectives is to use linearly interpolate and extrapolate the logs of the ground motion hazard curve. The interpolation increment is log(1.05), and the minimum and maximum bounds are calculated as follows:

<img src="https://latex.codecogs.com/svg.image?S_{a,min}=0.10\cdot S_{a,UH}"/></br>
<img src="https://latex.codecogs.com/svg.image?S_{a,max} = 10.0\cdot S_{a,UH}"/></br>


where  <img src="https://latex.codecogs.com/svg.image?S_{a,UH}"/> is the uniform hazard ground motion level (e.g., corresponding with the 2475-year return period for ASCE7).

An example of an interpolated hazard curve is shown below for Los Angeles, CA. Note that the linear extrapolation in log-space seems to potentially over-predict exceedance rates at larger shaking levels. A potential refinement may be to use cubic splins in log-space to allow for more curvature beyond the raw data range. However, further discussion is warranted with regards to whether or not hazard curves (truncated or not) should be extrapolated in this manner for this application, and what the implication would be of generating fragility curves that don't reach values of close to 1.0.


    
![png](2-Risk-Targeted-Calc-Procedure_files/2-Risk-Targeted-Calc-Procedure_6_0.png)
    


## 2.3. Fragility curve calculation

The notional fragility curve can be defined by three parameters: 
1. The target collapse probability (e.g. 10% for ASCE7, 5% for AASHTO), conditioned (ultimately) on the design ground motion level. 
2. The design ground motion level on which the target collapse probability is condition. Initially this is taken as the uniform-hazard value (<img src="https://latex.codecogs.com/svg.image?S_{a,UH}"/>), and is iterated on until the resulting fragility curve produces the target collapse risk.
3. The the lognormal standard deviation of the collapse capacity, <img src="https://latex.codecogs.com/svg.image?\beta"/>. The uncertainty in the collapse capacity (or fragility standard deviation) comes from a combination of record-to-record variability, variability in construction quality, material properties, nonstructural components, and other structural characteristics.

Assuming that the specified ground motion level <img src="https://latex.codecogs.com/svg.image?S_{a,UH}"/> is simply the targeted percentile of the collapse capacity (p), we can obtain the moments of the log-normal distribution, where the median is determined via:

<img src="https://latex.codecogs.com/svg.image?\ln\mu_{c} = \ln(S_{a,UH})-\Phi^{-1}(p)\cdot\beta"/>


where <img src="https://latex.codecogs.com/svg.image?\Phi^{-1}"/> is the inverse of the standard normal cumulative distribution function, also known as the *quantile function* or *percent point function*, and  <img src="https://latex.codecogs.com/svg.image?\beta"/> is the specified standard deviation. 

The resulting fragility curve is shown below for the Los Angeles site, conditioned on the 2,475-year <img src="https://latex.codecogs.com/svg.image?S_{a,UH}"/>. The derivative of the fragility curve can be thought of as the probability density function of the collapse capacity, which is calculated via:

 <img src="https://latex.codecogs.com/svg.image?f_{capacity}(c) = \phi\large[\frac{\ln c - \ln \mu_c}{\beta}\large]\cdot\frac{1}{c\beta}"/></br>


    
![png](2-Risk-Targeted-Calc-Procedure_files/2-Risk-Targeted-Calc-Procedure_8_1.png)
    


## 2.4. Calculation of total collapse probability

The total, annualized rate of collapse (<img src="https://latex.codecogs.com/svg.image?\lambda_{Col}"/>) can be obtained via numerical solution of the well-known "risk-integral" (e.g. McGuire, 2004), as follows: 


<img src="https://latex.codecogs.com/svg.image?\lambda_{Col} = \sum^{N_c}_{i=1}\lambda_{S_a>c}\cdot f_{Capacity}(c)\Delta c"/>

where *c* is the collapse capacity (expressed in terms of the intensity measure of interest), <img src="https://latex.codecogs.com/svg.image?f_{Capacity}(c)"/> is the probability density function of the collapse capacity (described above), which is essentially the derivative of the conditional collapse fragility curve. <img src="https://latex.codecogs.com/svg.image?\lambda_{S_a>c}"/> is the annualized rate at which the ground motion intensity exceeds the collapse capacity, which is simply the user-provided ground motion hazard curve. 

- Total probability equation for risk calculation
- Component breakdown and plots for each
- Final cumulative probability of exceedance plot (and target)

The product of the two terms within the summation is numerically integrated using a cumulative trapezoidal algorithm to obtain the cumulative annualized collapse frequency. Both plots are shown below. Despite being an intermediate step in the risk calculation, the product (defined here as the "annual collapse frequency *density*) can be useful in understanding where on the ground motion hazard curve the risk is concentrated. In this case, <img src="https://latex.codecogs.com/svg.image?S_a(1.0)"/> values between roughly 0.40 and 6.0 g contribute most to the risk (admittedly a somewhat broad range). This suggests shaking intensities below 0.40 g level are too low to have any significant probability of collapse (note that the median collapse capacity is roughly 5 g, based on the 10% conditional collapse probability being anchored at the 2475-year <img src="https://latex.codecogs.com/svg.image?S_a(1.0)"/> of about 2 g, and that shaking intensities exceeding 6.0 g occur too rarely to contribute to the risk of collapse.

    
![png](2-Risk-Targeted-Calc-Procedure_files/2-Risk-Targeted-Calc-Procedure_11_0.png)
    


#### Converting from annualized collapse risk to collapse probability over a specified time horizon

The maximum of the cumulative annual collapse frequency represents the total annualized collapse risk - in this case 1.75x10<sup>-4</sup> yr<sup>-1</sup>. Since the risk targets in ASCE 7 and AASHTO are specified in terms of a percent probability of collapse over a given timeframe (e.g, 1% in 50 years for ASCE 7 and 1.5% in 75 years for AASHTO), it is useful to convert the annualized collapse risk to a percent probability of collapse in *Y* years via:

<img src="https://latex.codecogs.com/svg.image?\mathrm{P}[Col] = 1-(1-\lambda_{col})^Y"/>


In this example, when we assume 10% probability of collapse under uniform hazard motions, the resulting 50-year collapse risk is roughly 0.87%, which is slightly below the 1.0% in 50 year target specified in ASCE 7. This, therefore necessitates some iteration in order to reach a design ground motion level that satisfies the risk target.

## 2.5. Iterative solution for obtaining risk-targeted ground motion (RTGM)

An iterative solution is employed in order to obtain the design ground motion that results in the specified risk target. The algorithm is based on generating an initial guess for the risk-targeted motion, calculating the resulting collapse risk and comparing it to the target, using the error result to generate a new guess and repeating the process. This process is described in more detail herein.

1. As described in previous sections, the initial RTGM guess is taken as the uniform hazard level motion - in the case of ASCE 7 in this example, this is the 2475-year <img src="https://latex.codecogs.com/svg.image?S_a(1.0)"/>, which is 2.04 g.

2. The collapse fragility curve is generated according to Section 2.3, and the collapse risk is calculated according to Section 2.4. 

3. The error between the calculated the target annualized collapse risks for iteration *i* is determined via <img src="https://latex.codecogs.com/svg.image?\mathrm{err}_i = \lambda_{col,i}/\lambda_{col,tgt}"/>

4. If <img src="https://latex.codecogs.com/svg.image?|\mathrm{err}_i-1|"/>

 is less than the error tolerance (0.01 is used in this implementation), i.e. the calculated risk is within 1% of the target, then the RTGM guess is adequate, and the algorthim can terminate. Otherwise, a subsequent guess must be generated. 

5. For the second iteration, the RTGM guess is calculated as <img src="https://latex.codecogs.com/svg.image?IM_2 = \mathrm{err}_{1}\cdot IM_1"/>. For all subsequent iterations, the RTGM guess is obtained by log-linear interpolation of all previous guesses, where the x-values are the computed annualized collapse risks, the y-values are the RTGM guess, and the value at which the interpolation is evaluated is the target collapse risk - in the ASCE 7 case, the target value is 2.0x10<sup>-4</sup> yr<sup>-1</sup>.

The maximum number of iterations is 10, although numerous previous test cases have shown that the algorithm in most converges within 3 iterations, while the largest known number of iterations required in a previous calculation was 7. 

The full iterative calculation results for the LA example is shown in the summary plots below. The final, 1% in 50-year risk-targeted <img src="https://latex.codecogs.com/svg.image?S_a(1.0)"/> for the LA site was 1.95 g, a roughly 5.5% decrease in comparison to the 2% in 50-year uniform hazard motion. 

    
![png](2-Risk-Targeted-Calc-Procedure_files/2-Risk-Targeted-Calc-Procedure_14_0.png)
    

