# A Practical Windows Guide to Setting Up Git and GitLab on Your USGS Machine

## Before you start:
1. Download git https://git-scm.com/downloads - once it has been downloaded search for "GitBash" on your computers apps to use the unix shell 
2. Create a personal account on GitHub - https://github.com/
3. Create your USGS account on GitLab - https://code.usgs.gov/


## 1. Using Unix Shell-type Commands (optional, but highly recommended)

### 1.1 - Software Carpentry: 
http://swcarpentry.github.io/shell-novice/ (~2-4 hours).  - You don’t need to master all of this material, but you need to know the basics. Getting as far section 3 should be sufficient (working with Files and Directories).


## 2. Git and GitHub introduction (optional, but highly recommended)

### 2.1. Beginner Git Resources
If you’ve never worked with git and github, it’s going to be confusing at first. Please do your best to understand the basics. Review and work through these introductory guides (or search the web for other introductory material):
-	https://guides.github.com/introduction/git-handbook/
-	https://towardsdatascience.com/getting-started-with-git-and-github-6fcd0f2d4ac6

### 2.2. Intermediate Git Resources
If those were easy/fast, please review: http://swcarpentry.github.io/git-novice/ (~2-3 hours)
-	I recommend you review the table of contents for the Software Carpentry lessons, and decide for yourself which components will be most valuable based on your experience. Make sure you attempt the relevant exercises!


## 3. Configuring Git on your USGS Machine

### 3.1.	Tutorial on Git/GitLab at USGS from Eric Martinez
- [video here](https://doimspp-my.sharepoint.com/personal/khaynie_usgs_gov/_layouts/15/onedrive.aspx?id=%2Fpersonal%2Fkhaynie%5Fusgs%5Fgov%2FDocuments%2FRecordings%2FGHSC%20HazDev%20Summer%20Python%20Tutorial%20Series%2D20210616%5F120131%2DMeeting%20Recording%2Emp4&parent=%2Fpersonal%2Fkhaynie%5Fusgs%5Fgov%2FDocuments%2FRecordings). The main commands are shown below, but I still would HIGHLY recommend taking the ~1 hour to watch Eric’s presentation, it’ll benefit in the long run

### 3.2. Configuring the DOI SSL Intercept
Using GitBash or another shell:
```
$ curl -o ~/cacert.pem -sSL https://curl.haxx.se/ca/cacert.pem
$ curl -sSLO http://sslhelp.doi.net/docs/DOIRootCA2.cer
```
(Note: you will need to be on the network for the second command to work)
```
$ cat DOIRootCA2.cer >> cacert.pem
```


## 3.3 Adding the appropriate environment variables
- OK so now we need to add a couple of environment variables that refer to `cacert.pem`
- One is `SSL_CERT_FILE`, and the other is `PIP_CERT`
- Windows users can do this by searching for "Edit environment variables for your account" in the windows bar, hitting "New" in the Environment Variables window, and then adding each of the variables as shown below - "cacert.pem" should reside in your user home directory


![alt text](GitGuideFigs\envVar.png "Configuring User Environment Variables")

## 4. Git Configuration
- Some additional things we need to configure in Git


```
$ git config --global core.autocrlf false
$ git config --global core.safecrlf false
$ git config --global user.name "FIRSTNAME LASTNAME"
$ git config --global user.email YOUREMAIL@USGS.GOV
$ git config --global http.sslcainfo ~/cacert.pem
```

# 5. GitLab <font color='crimson'>(in progress)</font>
- Log in here with your PIV: [code.usgs.gov/users/sign_in](code.usgs.gov/users/sign_in)
- Creating a Personal access tokens
    - In "Access Tokens" on the GitLab profile https://docs.gitlab.com/ee/user/profile/personal_access_tokens.html#creating-a-personal-access-token


### 5.1  Local Development <font color='crimson'>(From NSHMP Software Channel Wiki)</font>

To have internal GitLab projects downloaded as dependencies you must configure a gradle.properties file under the `$GRADLE_USER_HOME` directory, defaults to `$USER_HOME/.gradle.` The contents of the `gradle.properties` file should at minimum include:


```
git.nshmp.username=<user@usgs.gov>
git.nshmp.password=<gitlab-api-token>
```


where `<user@usgs.gov>` is replaced with you USGS email and `<gitlab-api-token>` is replaced with your GitLab API token.


### 5.2. GitLab Pipelines <font color='crimson'>(From NSHMP Software Channel Wiki)</font>

To ensure the GitLab pipelines continue to work and can download other GitLab repositories as dependencies you must add the GitLab CI variable `GITLAB_API_TOKEN` under your user: `https://code.usgs.gov/groups/ghsc/users/<user>/-/settings/ci_cd`

### 5.3. Forking and Cloning GitLab Repositories 
To be able fork and clone repositories, you need to be added to the https://code.usgs.gov/ghsc/users/ directory on GitLab – please contact Eric Martinez (emartinez@usgs.gov) to be added

