import json
import os
import sys

from rtgmpy.BuildingCodeRTGM import BuildingCodeRTGM


curDir = os.path.dirname(os.path.realpath(__file__))
srcDir = os.path.abspath(os.path.join(curDir, ".."))
sys.path.append(srcDir)


# Function for running
def run_rtgm(csvPath, codeString, outPath=None):
    # Initialize with default (random) site data
    rt = BuildingCodeRTGM(BldgCode=codeString)
    # Override with path to hazard curve inputs
    rt.read_from_csv(csvPath=csvPath)
    # Run risk calculation
    rt.calc_rtgm()

    if outPath:
        # Output data
        fname = os.path.basename(outPath).split(".json")[0]
        # If the parent directory exists...
        outDir = os.path.abspath(os.path.join(outPath, ".."))
        if os.path.isdir(outDir):
            outFiles = [file for file in os.listdir(outDir) if ".json" in file]
            # If there isn't a conflict, go ahead and create the original name
            if fname + ".json" not in outFiles:
                outName = outPath
            # Otherwise we append integers until a unique filename is found
            else:
                suff = 1
                outTest = "%s-%d.json" % (fname, suff)
                while outTest in outFiles:
                    suff += 1
                    outTest = "%s-%d.json" % (fname, suff)
                outName = os.path.join(outDir, outTest)
        # If the parent directory doesn't exist...
        else:
            newDir = os.path.abspath(os.path.join(outPath, ".."))
            os.mkdir(newDir)
            outName = outPath

        # Dump the dictionary results
        with open(outName, "w") as f:
            json.dump(rt.DATA, f)

    return rt.DATA


# Extracting input params from system arguments
args = sys.argv
codeString = args[1]
csvPath = args[2]

# Try extracting output path (if provided)
try:
    outPath = args[3]
except (IndexError):
    outPath = os.path.join(srcDir, "json-output", "output.json")

if __name__ == "__main__":
    if outPath == "no-output":
        data = run_rtgm(csvPath, codeString, outPath=None)
    else:
        data = run_rtgm(csvPath, codeString, outPath)
