import os
import sys

import numpy as np
import pytest

import rtgmpy as rtg


homePath = os.path.dirname(os.path.realpath(__file__))
srcpath = os.path.abspath(os.path.join(homePath, ".."))
sys.path.append(srcpath)


def test_default_single():
    # Test initialization with default
    RTGM = rtg.RiskTargetedGMCalc()
    # Test that default rtgm calculation works without crashing
    RTGM.calc_rtgm(0.01, 50)
    # Check that computed risk == target (within tolerance)
    tgt = RTGM.riskTgtAnnual
    actual = RTGM.data["RTGM"]["iterations"][-1]["colRisk_Annual"]
    assert np.abs(actual / tgt) - 1 <= RTGM.errTol, (
        "Computed risk error out of tolerance for random site %s" % RTGM.siteID
    )


def test_default_multi():
    # Test initialization with default
    MULT = rtg.MultiRTGMcalc()
    MULT.calc_rtgm_all(0.01, 50)
    # Checking computed collapse risks
    tgt = MULT.DATA["riskTargets"]["riskTgt_Annual"]
    errCheck = np.abs(MULT.summaryDF["colRisk_annual"] / tgt) - 1 <= MULT.errTol
    assert errCheck.all(), (
        "Computed risk error(s) out of tolerance for random site %s" % MULT.siteData["name"]
    )


def test_default_bldcode():
    # Test initialization with default
    BLD = rtg.BuildingCodeRTGM()
    # Compile data - automatically performs risk-calc
    BLD.calc_rtgm()
    # Checking computed collapse risks
    tgt = BLD.DATA["riskTargets"]["riskTgt_Annual"]
    errCheck = np.abs(BLD.summaryDF["colRisk_annual"] / tgt) - 1 <= BLD.errTol
    assert errCheck.all(), (
        "Computed risk error(s) out of tolerance for random site %s" % BLD.siteData["name"]
    )
