import json
import os

import numpy as np
import pytest

import rtgmpy as rtg


homePath = os.path.dirname(os.path.realpath(__file__))
srcpath = os.path.abspath(os.path.join(homePath, "..", "rtgmpy"))
exDir = os.path.join(srcpath, "example-haz-inputs", "all-IMs")


class ExampleSite(object):
    def __init__(self, filesPath):
        files = [file for file in os.listdir(filesPath) if ".json" in file]
        # Load as json
        self.exampleHaz = []
        for file in files:
            with open(os.path.join(filesPath, file)) as fp:
                self.exampleHaz.append(json.load(fp))


def get_risk_error(BldgCode, hazDict):
    # Test initialization with default
    BLD = rtg.BuildingCodeRTGM(BldgCode=BldgCode, siteDict=hazDict)
    BLD.calc_rtgm()
    # Checking computed collapse risks
    tgt = BLD.DATA["riskTargets"]["riskTgt_Annual"]
    errCheck = np.abs(BLD.summaryDF["colRisk_annual"] / tgt) - 1 <= BLD.errTol
    return errCheck, BLD


@pytest.mark.parametrize("BldgCode", ["ASCE7", "AASHTO"])
@pytest.mark.parametrize("site_input", ExampleSite(exDir).exampleHaz)
def test_example_sites(BldgCode, site_input):
    (errCheck, BLD) = get_risk_error(BldgCode, site_input)
    checkFalseIMs = list(errCheck.keys()[errCheck == False])
    assert errCheck.all(), "%s computed risk error(s) out of tolerance for site %s (%s)" % (
        BLD.siteData["name"],
        BldgCode,
        checkFalseIMs,
    )
